# Grortir

Application for supporting optimization of production process.

[![Build Status](http://img.shields.io/travis/qbahn/grortir/master.svg)](https://travis-ci.org/qbahn/grortir)
[![Coverage Status](http://img.shields.io/coveralls/qbahn/grortir/master.svg)](https://coveralls.io/r/qbahn/grortir)
[![Code Issues](https://www.quantifiedcode.com/api/v1/project/51365120fa014dbd860e332bbc1bee02/badge.svg)](https://www.quantifiedcode.com/app/project/51365120fa014dbd860e332bbc1bee02)
[![Code Health](https://landscape.io/github/qbahn/grortir/master/landscape.svg?style=flat)](https://landscape.io/github/qbahn/grortir/master)
[![Scrutinizer Code Quality](http://img.shields.io/scrutinizer/g/qbahn/grortir.svg)](https://scrutinizer-ci.com/g/qbahn/grortir/?branch=master)
[![PyPI Version](http://img.shields.io/pypi/v/Grortir.svg)](https://pypi.python.org/pypi/Grortir)
[![PyPI Downloads](http://img.shields.io/pypi/dm/Grortir.svg)](https://pypi.python.org/pypi/Grortir)

## Getting Started
Check documentation site:

[http://qbahn.github.io/grortir/gettingStarted/](http://qbahn.github.io/grortir/gettingStarted/)

## Documentation
Read the full documentation:
 
### [http://qbahn.github.io/grortir](http://qbahn.github.io/grortir)

## For contributors
Check documentation site:

[http://qbahn.github.io/grortir/about/contributing/](http://qbahn.github.io/grortir/about/contributing/)

